package com.bocloud.sms.booter.config;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.InitializingBean;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson.JSONObject;
import com.bocloud.sms.entity.Dictionary;
import com.bocloud.sms.interfaces.DictService;

import lombok.extern.slf4j.Slf4j;

/**
 * @author tyl
 * @since 2020/3/25 周三 14:06
 */
@Component
@Slf4j
public class DictCache implements InitializingBean {

    private final StringRedisTemplate redisTemplate;
    private final DictService dictService;
    private final ThreadPoolTaskExecutor taskExecutor;

    public DictCache(StringRedisTemplate redisTemplate, DictService dictService, ThreadPoolTaskExecutor taskExecutor) {
        this.redisTemplate = redisTemplate;
        this.dictService = dictService;
        this.taskExecutor = taskExecutor;
    }

    public void putCache(String code, String value) {
        String key = Dictionary.class.getSimpleName() + "_" + code;
        this.redisTemplate.opsForValue().set(key, value);
    }

    @Override
    public void afterPropertiesSet() {
        taskExecutor.execute(this::addOsNamesCache);
        taskExecutor.execute(this::addDataCenterCache);
    }

    public void addOsNamesCache() {
        try {
            List<String> list = dictService.getAllOsName();
            putCache("OS_CATEGORY_TASK", JSONObject.toJSONString(list));
        } catch (Exception e) {
            log.error("put os name cache error,", e);
        }
    }

    public void addDataCenterCache() {
        try {
            Map<String,String> map = dictService.getAllDataCenter();
            putCache("DATA_CENTER", JSONObject.toJSONString(map));
        } catch (Exception e) {
            log.error("put data center cache error,", e);
        }
    }
}
