package com.bocloud.sms.booter.controller;

import com.bocloud.sms.entity.Icon;
import com.bocloud.sms.interfaces.IconService;
import com.megatron.common.model.GeneralResult;
import com.megatron.common.model.GridBean;
import com.megatron.common.model.Pager;
import com.megatron.common.model.RequestContext;
import com.megatron.common.utils.Common;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 图标controller层
 *
 * @author 胡立伟
 * @Version 1.0
 * @since 2020年4月7日
 */
@RestController
@RequestMapping("/v1/icon")
@Tag(name = "图标管理")
public class IconController {
    @Autowired
    private IconService iconService;

    /**
     * 图标列表查询
     *
     * @return 图标列表
     */
    @GetMapping
    @Operation(summary = "图标列表查询")
    public GeneralResult<GridBean<Icon>> list(Pager pager, @Value(Common.REQ_CONTEXT) RequestContext context) {
        return iconService.list(pager, context);
    }

    /**
     * 上传图标
     *
     * @param files   图标文件
     * @param context 上下文
     * @return 上传结果
     */
    @PostMapping()
    @Operation(summary = "上传图标")
    public GeneralResult<Void> upload(MultipartFile[] files, String category, @Value(Common.REQ_CONTEXT) RequestContext context) {
        return iconService.create(files, category, context);
    }

    /**
     * 删除图标
     *
     * @param id 图标id
     * @return 删除结果
     */
    @DeleteMapping(value = "/{id}")
    @Operation(summary = "删除图标")
    public GeneralResult<Void> remove(@PathVariable(value = Common.ID) Long id) {
        return iconService.remove(id);
    }
}
