package com.bocloud.sms.interfaces;

import com.megatron.common.model.GeneralResult;
import com.megatron.common.model.Pager;
import com.megatron.common.model.RequestContext;
import com.megatron.common.model.Result;
import com.bocloud.sms.entity.UserGroup;
import com.bocloud.sms.model.UserGroupBean;

import java.util.List;

/**
 * 用户组抽象Service接口
 *
 * @author hongqingyu
 */
public interface UserGroupService {

    /**
     * 创建用户组
     *
     * @param userGroup 用户组信息
     * @param context
     * @return
     */
    Result create(UserGroup group, RequestContext context);

    /**
     * 删除
     *
     * @param id
     * @param context
     * @return
     */
    Result remove(Long id, RequestContext context);

    /**
     * 编辑
     *
     * @param userGroupBean
     * @param context
     * @return
     */
    Result modify(UserGroupBean bean, RequestContext context);

    /**
     * 详情
     *
     * @param id
     * @return
     */
    GeneralResult<UserGroup> detail(Long id);

    /**
     * 列表
     *
     * @param pager
     * @return
     */
    GeneralResult list(Pager pager);

    /**
     * 配置用户
     *
     * @param userIds
     * @param id
     * @return
     */
    Result configUser(List<Long> userIds, Long id);

    /**
     * 根据用户id查询关联的用户组id
     *
     * @param userId
     * @return
     */
    GeneralResult listGroupIdByUserId(Long userId);

    /**
     * 根据用户组id查询用户信息
     *
     * @param pager   分页信息
     * @param groupId 用户组id
     * @return 用户分页信息
     */
    GeneralResult listUserByGroupId(Pager pager, Long groupId);

    /**
     * 查询全部用户组
     *
     * @return
     */
    GeneralResult listAll();
}
