package com.bocloud.sms.repository;

import com.bocloud.sms.entity.ApiToken;
import com.megatron.common.exception.DataBaseException;
import com.megatron.common.model.Pager;
import com.megatron.common.utils.Common;
import com.megatron.common.utils.MapTools;
import com.megatron.database.core.intf.impl.BasicGenericDao;
import com.megatron.database.utils.QueryBuilder;
import com.megatron.framework.core.CurrentService;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * api token访问控制类
 */
@Repository("apiTokenRepository")
public class ApiTokenRepository extends BasicGenericDao<ApiToken, Long> {

    public ApiTokenRepository(JdbcTemplate jdbcTemplate, NamedParameterJdbcTemplate npJdbcTemplate, CurrentService service) {
        super(jdbcTemplate, npJdbcTemplate, service);
    }

    public ApiToken get(String token) throws Exception {
        String sql = "select * from api_token where enabled = true and token = :token";
        Map<String, Object> params = MapTools.simpleMap(Common.TOKEN, token);
        List<ApiToken> list = this.list(ApiToken.class, sql, params);
        return list.isEmpty() ? null : list.get(0);
    }

    public List<ApiToken> list(Pager pager) {
        String sql = "select * from api_token a where a.is_deleted = 0";
        sql = getQueryBuilder().buildRaw(sql, pager, "a");
        Map<String, Object> param = getQueryBuilder().getParam(pager.getParams());
        return this.list(ApiToken.class, sql, param);
    }

    public int count(Pager pager) {
        String sql = "select count(1) from api_token a where a.is_deleted= 0";
        sql = getQueryBuilder().buildRaw(sql, pager.getParams(), null, "a");
        Map<String, Object> param = getQueryBuilder().getParam(pager.getParams());
        return this.countQuery(sql, param).intValue();
    }

    public List<ApiToken> listAll() throws Exception {
        String sql = "select a.* from api_token a where a.is_deleted = 0";
        return this.list(ApiToken.class, sql);
    }

    public ApiToken query(Long id) {
        String sql = "select a.* from api_token a where a.is_deleted = 0 and a.id = :id";
        Map<String, Object> paramMap = MapTools.simpleMap("id", id);
        List<ApiToken> list = this.list(ApiToken.class, sql, paramMap);
        return list.isEmpty() ? null : list.get(0);
    }

    public boolean delete(Long id, Long menderId) throws DataBaseException {
        String sql = "update api_token set is_deleted = 1, gmt_modify = :gmtModify, mender_id = :menderId where id = :id";
        Map<String, Object> params = MapTools.simpleMap("id", id);
        params.put("gmtModify", new Date());
        params.put("menderId", menderId);
        return this.execute(sql, params) > 0;
    }
}
